@@ -131,10 +131,12 @@ class PyCTPP2TemplateRenderer(object):
 
     @property
     def template(self):
-        if len(self.tmpl_settings.path):
-            tmpl_path = [abspath_from_asset_spec(p) for p in self.tmpl_settings.path]
-            self.engine.path = self.engine.path + tmpl_path
-            self.tmpl_settings.path = []
+        tmpl_path = [abspath_from_asset_spec(p) for p in self.tmpl_settings.path]
+        self.engine.path = self.path + tmpl_path
+
+        for domain, folder in self.tmpl_settings.locales.items():
+            folder = abspath_from_asset_spec(folder)
+            self.engine.add_translation(domain, folder)
 
         isabs = os.path.isabs(self.info.name)
 
@@ -156,12 +158,6 @@ class PyCTPP2TemplateRenderer(object):
         return self.engine.parse(filename)
 
     def __call__(self, value, system):
-        if len(self.tmpl_settings.locales):
-            for domain, folder in self.tmpl_settings.locales.items():
-                folder = abspath_from_asset_spec(folder)
-                self.engine.add_translation(domain, folder)
-            self.tmpl_settings.locales = {}
-
         loc = None
         if 'request' in system:
             loc = get_locale_name(system['request'])
